render_decode_chunk

Function render_decode_chunk 

pub fn render_decode_chunk<'scope, T, F>(
    scope: Scope<'scope, T>,
    format: F,
    record_chunks: StreamVec<'scope, T, Result<F::RecordChunk, StorageErrorX>>,
    mfp: SafeMfpPlan,
) -> (StreamVec<'scope, T, Result<Row, StorageErrorX>>, PressOnDropButton)
where T: Timestamp, F: OneshotFormat + 'static,
Render an operator that given a stream of OneshotFormat::RecordChunks will decode these chunks into a stream of Rows.