render_split_work

Function render_split_work 

pub fn render_split_work<'scope, T, S, F>(
    scope: Scope<'scope, T>,
    collection_id: GlobalId,
    objects: StreamVec<'scope, T, Result<(S::Object, S::Checksum), StorageErrorX>>,
    source: S,
    format: F,
) -> (StreamVec<'scope, T, Result<F::WorkRequest<S>, StorageErrorX>>, PressOnDropButton)
where T: Timestamp, S: OneshotSource + Send + Sync + 'static, F: OneshotFormat + Send + Sync + 'static,
Render an operator that given a stream of OneshotSource::Objects will split them into units of work based on the provided OneshotFormat.