OneshotObject

Trait OneshotObject 

pub trait OneshotObject {
    // Required methods
    fn name(&self) -> &str;
    fn path(&self) -> &str;
    fn size(&self) -> usize;
    fn encodings(&self) -> &[Encoding];
}
An object that will be fetched from a OneshotSource.

Required Methods

fn name(&self) -> &str

Name of the object, including any extensions.

fn path(&self) -> &str

Path of the object within the remote source.

fn size(&self) -> usize

Size of this object in bytes.

fn encodings(&self) -> &[Encoding]

Encodings of the entire object, if any.

Note: The object may internally use compression, e.g. a Parquet file could compress its column chunks, but if the Parquet file itself is not compressed then this would return None.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors