render_initialization_operator

Function render_initialization_operator 

fn render_initialization_operator<'scope>(
    scope: Scope<'scope, Timestamp>,
    sink_id: GlobalId,
    up_to: Antichain<Timestamp>,
    err_stream: StreamVec<'scope, Timestamp, (DataflowError, Timestamp, Diff)>,
) -> (StreamVec<'scope, Timestamp, Result<(), String>>, PressOnDropButton)
Renders the ‘initialization’ operator, which does work on the leader worker only.

The leader worker receives all errors from the err_stream and if it encounters any errors will early exit and broadcast the error on the returned start_stream, to avoid any unnecessary work across all workers.

Returns the start_stream with an error received in the err_stream, if any, otherwise Ok(()).