fn render_upload_operator<'scope, T>(
scope: Scope<'scope, Timestamp>,
connection_context: ConnectionContext,
aws_connection: AwsConnection,
connection_id: CatalogItemId,
connection_details: S3UploadInfo,
sink_id: GlobalId,
input_collection: StreamVec<'scope, Timestamp, Vec<ColumnationStack<((Row, ()), Timestamp, Diff)>>>,
up_to: Antichain<Timestamp>,
start_stream: StreamVec<'scope, Timestamp, Result<(), String>>,
params: CopyToParameters,
output_batch_count: u64,
) -> (StreamVec<'scope, Timestamp, Result<u64, String>>, PressOnDropButton)where
T: CopyToS3Uploader,Expand description
Renders the upload operator, which waits on the start_stream to ensure
initialization is complete and then handles the uploads to S3.
Returns a completion_stream which contains 1 event per worker of
the result of the upload operation, either an error or the number of rows
uploaded by the worker.
The input_collection must be a stream of chains, partitioned and exchanged by the row’s hash
modulo the number of batches.